@@ -1,3 +1,6 @@
+# Copyright (c) Acconeer AB, 2022
+# All rights reserved
+
 import abc
 import logging
 
@@ -41,6 +44,9 @@ class BaseClient(abc.ABC):
 
         if not info.get("mock"):
             try:
+                sensor = info.get("sensor")
+                if sensor and sensor != "a111":
+                    raise ClientError(f"Wrong sensor version, expected a111 but got {sensor}")
                 log.info("reported version: {}".format(info["version_str"]))
 
                 if info["strict_version"] < version.parse(SDK_VERSION):
@@ -245,6 +251,12 @@ class SessionSetupError(ClientError):
 
 
 def decode_version_str(version_str: str) -> dict:
+    if version_str.startswith("a111-"):
+        version_str = version_str[5:]
+
+    if version_str.startswith("v"):
+        version_str = version_str[1:]
+
     if "-" in version_str:
         strict_version = version.parse(version_str.split("-")[0])
     else:
