@@ -1,7 +1,7 @@
 # Copyright (c) Acconeer AB, 2022
 # All rights reserved
 
-from . import plugin
+from . import plugin_components, utils
 from .app_model_viewer import AppModelViewer
 from .main_window import MainWindow
 from .misc import BUTTON_ICON_COLOR
